import * as cdk from '@aws-cdk/core';
/**
 * A resource provider for Aqua Enterprise Scanner.
 *
 * @schema CfnScannerProps
 */
export interface CfnScannerProps {
    /**
     * EKS cluster name.
     *
     * @schema CfnScannerProps#ClusterID
     */
    readonly clusterId?: string;
    /**
     * Secrets Manager ARN for kubeconfig file.
     *
     * @schema CfnScannerProps#KubeConfig
     */
    readonly kubeConfig?: string;
    /**
     * IAM to use with EKS cluster authentication, if not resource execution role will be used.
     *
     * @schema CfnScannerProps#RoleArn
     */
    readonly roleArn?: string;
    /**
     * Namespace to use with helm.
     *
     * Created if doesn't exist and default will be used if not provided
     *
     * @schema CfnScannerProps#Namespace
     */
    readonly namespace?: string;
    /**
     * Name for the helm release.
     *
     * @schema CfnScannerProps#Name
     */
    readonly name?: string;
    /**
     * Custom Values can optionally be specified.
     *
     * @schema CfnScannerProps#Values
     */
    readonly values?: any;
    /**
     * String representation of a values.yaml file.
     *
     * @schema CfnScannerProps#ValueYaml
     */
    readonly valueYaml?: string;
    /**
     * Version can be specified, if not latest will be used.
     *
     * @schema CfnScannerProps#Version
     */
    readonly version?: string;
    /**
     * Custom Value Yaml file can optionally be specified.
     *
     * @schema CfnScannerProps#ValueOverrideURL
     */
    readonly valueOverrideUrl?: string;
    /**
     * Timeout for resource provider.
     *
     * Default 60 mins
     *
     * @schema CfnScannerProps#TimeOut
     */
    readonly timeOut?: number;
    /**
     * For network connectivity to Cluster inside VPC.
     *
     * @schema CfnScannerProps#VPCConfiguration
     */
    readonly vpcConfiguration?: CfnScannerPropsVpcConfiguration;
}
/**
 * Converts an object of type 'CfnScannerProps' to JSON representation.
 */
export declare function toJson_CfnScannerProps(obj: CfnScannerProps | undefined): Record<string, any> | undefined;
/**
 * For network connectivity to Cluster inside VPC.
 *
 * @schema CfnScannerPropsVpcConfiguration
 */
export interface CfnScannerPropsVpcConfiguration {
    /**
     * Specify one or more security groups.
     *
     * @schema CfnScannerPropsVpcConfiguration#SecurityGroupIds
     */
    readonly securityGroupIds?: string[];
    /**
     * Specify one or more subnets.
     *
     * @schema CfnScannerPropsVpcConfiguration#SubnetIds
     */
    readonly subnetIds?: string[];
}
/**
 * Converts an object of type 'CfnScannerPropsVpcConfiguration' to JSON representation.
 */
export declare function toJson_CfnScannerPropsVpcConfiguration(obj: CfnScannerPropsVpcConfiguration | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Aqua::Enterprise::Scanner`.
 *
 * @external
 * @cloudformationResource Aqua::Enterprise::Scanner
 * @link https://github.com/aquasecurity/aqua-helm.git
 */
export declare class CfnScanner extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     *
     * @external
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "Aqua::Enterprise::Scanner";
    /**
     * Resource props.
     *
     * @external
     */
    readonly props: CfnScannerProps;
    /**
     * Attribute `Aqua::Enterprise::Scanner.ID`.
     *
     * @external
     * @link https://github.com/aquasecurity/aqua-helm.git
     */
    readonly attrId: string;
    /**
     * Create a new `Aqua::Enterprise::Scanner`.
     *
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     * @external
     */
    constructor(scope: cdk.Construct, id: string, props: CfnScannerProps);
}
